@@ -23,8 +23,9 @@ from .service import (
     ServiceBlock,
     ServiceBuilder,
 )
+from .stepper import Step, Stepper, StepsBuilder
 
-__version__ = "0.1.2"
+__version__ = "0.1.6"
 __all__ = [
     "__version__",
     "BaseOrchServMsg",
@@ -44,4 +45,7 @@ __all__ = [
     "Service",
     "ServiceBlock",
     "ServiceBuilder",
+    "Stepper",
+    "StepsBuilder",
+    "Step",
 ]
